==> projectx-sdk-1.0.72-sources.jar: cn/com/duiba/projectx/sdk/component/task/dto/TaskItemConfig.java <==
package cn.com.duiba.projectx.sdk.component.task.dto;

import cn.com.duiba.projectx.sdk.component.base.OptionResult;

public class TaskItemConfig extends OptionResult {
    /**
     * 任务ID
     */
    private String id;
    /**
     * 任务标识
     */
    private String code;

    /**
     * 任务标题
     */
    private String title;

    /**
     * 任务描述
     */
    private String desc;

    /**
     * 任务图标
     */
    private String icon;

    /**
     * 按钮文案
     */
    private String buttonText;

    /**
     * 任务跳转URL
     */
    private String jumpUrl;

    /**
     * 任务限制类型
     * 0=不限制
     * 1=日
     * 2=周
     * 3=月
     * 4=永久
     */
    private Integer intervalType;

    /**
     * 任务名称
     */
    private Integer intervalLimitSize;

    /**
     * 是否发奖
     */
    private Boolean awardPrize;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl;
    }

    public Integer getIntervalType() {
        return intervalType;
    }

    public void setIntervalType(Integer intervalType) {
        this.intervalType = intervalType;
    }

    public Integer getIntervalLimitSize() {
        return intervalLimitSize;
    }

    public void setIntervalLimitSize(Integer intervalLimitSize) {
        this.intervalLimitSize = intervalLimitSize;
    }

    public Boolean getAwardPrize() {
        return awardPrize;
    }

    public void setAwardPrize(Boolean awardPrize) {
        this.awardPrize = awardPrize;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }
}

==> projectx-sdk-1.1.90-sources.jar: cn/com/duiba/projectx/sdk/component/task/dto/TaskItemConfig.java <==
package cn.com.duiba.projectx.sdk.component.task.dto;

import cn.com.duiba.projectx.sdk.component.base.OptionResult;

public class TaskItemConfig extends OptionResult {
    /**
     * 任务ID
     */
    private String id;
    /**
     * 任务标识
     */
    private String code;

    /**
     * 任务标题
     */
    private String title;

    /**
     * 任务副标题
     */
    private String subTitle;

    /**
     * 任务描述
     */
    private String desc;

    /**
     * 任务图标
     */
    private String icon;

    /**
     * 按钮文案
     */
    private String buttonText;

    /**
     * 任务跳转URL
     */
    private String jumpUrl;

    /**
     * 任务限制类型
     * 0=不限制
     * 1=日
     * 2=周
     * 3=月
     * 4=永久
     */
    private Integer intervalType;

    /**
     * 任务名称
     */
    private Integer intervalLimitSize;

    /**
     * 是否发奖
     */
    private Boolean awardPrize;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl;
    }

    public Integer getIntervalType() {
        return intervalType;
    }

    public void setIntervalType(Integer intervalType) {
        this.intervalType = intervalType;
    }

    public Integer getIntervalLimitSize() {
        return intervalLimitSize;
    }

    public void setIntervalLimitSize(Integer intervalLimitSize) {
        this.intervalLimitSize = intervalLimitSize;
    }

    public Boolean getAwardPrize() {
        return awardPrize;
    }

    public void setAwardPrize(Boolean awardPrize) {
        this.awardPrize = awardPrize;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getSubTitle() {
        return subTitle;
    }

    public void setSubTitle(String subTitle) {
        this.subTitle = subTitle;
    }
}
